@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2005-2007  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2005-2008  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -129,7 +129,7 @@ static gchar *class_to_icon_name(guint32 class)
 		case 0x05:
 			return "stock_landline-phone";
 		default:
-			return "stock_bluetooth";
+			return "bluetooth";
 		}
 	case 0x03:
 		return "network-wireless";
@@ -142,7 +142,7 @@ static gchar *class_to_icon_name(guint32 class)
 		case 0x02:
 			return "input-mouse";
 		default:
-			return "stock_bluetooth";
+			return "bluetooth";
 		}
 	case 0x06:
 		switch ((class & 0xf0) >> 4) {
@@ -151,10 +151,10 @@ static gchar *class_to_icon_name(guint32 class)
 		case 0x08:
 			return "printer";
 		default:
-			return "stock_bluetooth";
+			return "bluetooth";
 		}
 	default:
-		return "stock_bluetooth";
+		return "bluetooth";
 	}
 }
 
