@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2005-2007  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2005-2008  Marcel Holtmann <marcel@holtmann.org>
  *  Copyright (C) 2006-2007  Bastien Nocera <hadess@hadess.net>
  *
  *
@@ -26,21 +26,20 @@
 #include <config.h>
 #endif
 
-#include <stdio.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <dbus/dbus-glib.h>
 
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
 
+#include "bluetooth-instance.h"
+
 #include "general.h"
 #include "service.h"
 #include "adapter.h"
 
+static gboolean singleton = FALSE;
+
 static void delete_callback(GtkWidget *window, GdkEvent *event,
 						gpointer user_data)
 {
@@ -58,7 +57,7 @@ static void close_callback(GtkWidget *button, gpointer user_data)
 	gtk_main_quit();
 }
 
-static void create_window(GtkWidget *notebook)
+static GtkWidget *create_window(GtkWidget *notebook)
 {
 	GtkWidget *window;
 	GtkWidget *widget;
@@ -68,8 +67,8 @@ static void create_window(GtkWidget *notebook)
 
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(window), _("Bluetooth Preferences"));
-	gtk_window_set_icon_name(GTK_WINDOW(window), "stock_bluetooth");
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
+	gtk_window_set_default_size(GTK_WINDOW(window), 420, 420);
 	g_signal_connect(G_OBJECT(window), "delete-event",
 					G_CALLBACK(delete_callback), NULL);
 
@@ -108,12 +107,14 @@ static void create_window(GtkWidget *notebook)
 						widget, _("General"));
 
 	gtk_widget_show_all(window);
+
+	return window;
 }
 
 static void name_owner_changed(DBusGProxy *object, const char *name,
 			const char *prev, const char *new, gpointer user_data)
 {
-	if (!strcmp(name, "org.bluez") && *new == '\0') {
+	if (g_str_equal(name, "org.bluez") == TRUE && *new == '\0') {
 		disable_adapter();
 		disable_service();
 	}
@@ -139,8 +140,16 @@ static DBusGProxy *setup_manager(DBusGConnection *conn)
 	return proxy;
 }
 
+static GOptionEntry options[] = {
+	{ "singleton", 0, 0, G_OPTION_ARG_NONE, &singleton,
+			"Only allow one instance of this application", NULL },
+	{ NULL },
+};
+
 int main(int argc, char *argv[])
 {
+	BluetoothInstance *instance;
+	GtkWidget *window;
 	GtkWidget *notebook;
 	DBusGConnection *conn;
 	DBusGProxy *manager;
@@ -150,14 +159,29 @@ int main(int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gtk_init(&argc, &argv);
+	if (gtk_init_with_args(&argc, &argv, NULL,
+				options, GETTEXT_PACKAGE, &error) == FALSE) {
+		if (error) {
+			g_print("%s\n", error->message);
+			g_error_free(error);
+		} else
+			g_print("An unknown error occurred\n");
+
+		gtk_exit(1);
+	}
+
+	instance = bluetooth_instance_new("properties", singleton);
+	if (instance == NULL)
+		gtk_exit(0);
+
+	gtk_window_set_default_icon_name("bluetooth");
 
 	conn = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
 	if (error != NULL) {
 		g_printerr("Connecting to system bus failed: %s\n",
 							error->message);
 		g_error_free(error);
-		exit(EXIT_FAILURE);
+		gtk_exit(1);
 	}
 
 	setup_general();
@@ -168,7 +192,9 @@ int main(int argc, char *argv[])
 
 	manager = setup_manager(conn);
 
-	create_window(notebook);
+	window = create_window(notebook);
+
+	bluetooth_instance_set_window(instance, GTK_WINDOW(window));
 
 	gtk_main();
 
@@ -182,5 +208,7 @@ int main(int argc, char *argv[])
 
 	dbus_g_connection_unref(conn);
 
+	g_object_unref(instance);
+
 	return 0;
 }
