@@ -51,10 +51,6 @@ static GtkListStore *service_store;
 enum {
 	COLUMN_PATH,
 	COLUMN_IDENT,
-	COLUMN_RUNNING,
-	COLUMN_BUSY,
-	COLUMN_NAME,
-	COLUMN_DESCRIPTION,
 };
 
 static void show_service(const gchar *identifier)
@@ -81,130 +77,49 @@ static void show_service(const gchar *identifier)
 	gtk_widget_show(notebook);
 }
 
-static void startstop_notify(DBusGProxy *object,
-				DBusGProxyCall *call, void *user_data)
-{
-	gchar *path = user_data;
-	GtkTreeIter iter;
-	gboolean active;
-	gchar *identifier;
-
-	dbus_g_proxy_end_call(object, call, NULL, G_TYPE_INVALID);
-
-	if (gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(service_store),
-							&iter, path) == FALSE)
-		return;
-
-	dbus_g_proxy_call(object, "IsRunning", NULL, G_TYPE_INVALID,
-				G_TYPE_BOOLEAN, &active, G_TYPE_INVALID);
-
-	gtk_tree_model_get(GTK_TREE_MODEL(service_store), &iter,
-						COLUMN_IDENT, &identifier, -1);
-
-	gtk_list_store_set(service_store, &iter, COLUMN_RUNNING, active,
-						COLUMN_BUSY, FALSE, -1);
-
-	if (active == TRUE)
-		show_service(identifier);
-	else
-		gtk_widget_hide(notebook);
-}
-
-static void startstop_callback(GtkCellRendererToggle *renderer,
-					gchar *path, gpointer user_data)
-{
-	DBusGProxy *object;
-	GtkTreeIter iter;
-	const char *service_path;
-	gboolean active;
-
-	if (connection == NULL)
-		return;
-
-	if (gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(service_store),
-							&iter, path) == FALSE)
-		return;
-
-	gtk_tree_model_get(GTK_TREE_MODEL(service_store), &iter,
-					COLUMN_PATH, &service_path,
-					COLUMN_RUNNING, &active, -1);
-
-	object = dbus_g_proxy_new_for_name(connection, "org.bluez",
-					service_path, "org.bluez.Service");
-
-	gtk_list_store_set(service_store, &iter, COLUMN_BUSY, TRUE, -1);
-
-	if (active == FALSE) {
-		dbus_g_proxy_begin_call(object, "Start", startstop_notify,
-				g_strdup(path), g_free, G_TYPE_INVALID);
-		active = TRUE;
-	} else {
-		dbus_g_proxy_begin_call(object, "Stop", startstop_notify,
-				g_strdup(path), g_free, G_TYPE_INVALID);
-		active = FALSE;
-	}
-}
-
-static void status_to_toggle(GtkTreeViewColumn *column, GtkCellRenderer *cell,
-			GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
-{
-	gboolean active, progress;
-
-	gtk_tree_model_get(model, iter, COLUMN_RUNNING, &active,
-						COLUMN_BUSY, &progress, -1);
-
-	g_object_set(cell, "active", active, NULL);
-	g_object_set(cell, "sensitive", progress == TRUE ? FALSE : TRUE, NULL);
-}
-
-static void status_to_text(GtkTreeViewColumn *column, GtkCellRenderer *cell,
-			GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
-{
-	gboolean active, progress;
-	gchar *str;
-
-	gtk_tree_model_get(model, iter, COLUMN_RUNNING, &active,
-						COLUMN_BUSY, &progress, -1);
-
-	if (active == TRUE) {
-		if (progress == TRUE)
-			str = _("Stopping");
-		else
-			str = _("Running");
-	} else {
-		if (progress == TRUE)
-			str = _("Starting");
-		else
-			str = _("Stopped");
-	}
- 
-	g_object_set(cell, "text", str, NULL);
-}
-
 static void select_callback(GtkTreeSelection *selection, gpointer user_data)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean selected;
 	gchar *identifier;
-	gboolean running;
 
 	selected = gtk_tree_selection_get_selected(selection, &model, &iter);
 
 	if (selected == TRUE) {
-		gtk_tree_model_get(model, &iter, COLUMN_IDENT, &identifier,
-						COLUMN_RUNNING, &running, -1);
-
-		if (running == TRUE)
-			show_service(identifier);
-		else
-			gtk_widget_hide(notebook);
-
+		gtk_tree_model_get(model, &iter, COLUMN_IDENT, &identifier, -1);
+		show_service(identifier);
 		g_free(identifier);
 	} else
 		gtk_widget_hide(notebook);
 }
 
+static void ident_to_text(GtkTreeViewColumn *column, GtkCellRenderer *cell,
+			GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
+{
+	gchar *identifier, *text;
+
+	gtk_tree_model_get(model, iter, COLUMN_IDENT, &identifier, -1);
+	if (identifier == NULL)
+		text = "unknown";
+
+	if (g_ascii_strcasecmp(identifier, "network") == 0)
+		text = _("Network service");
+
+	if (g_ascii_strcasecmp(identifier, "input") == 0)
+		text = _("Input service");
+
+	if (g_ascii_strcasecmp(identifier, "audio") == 0)
+		text = _("Audio service");
+
+	if (g_ascii_strcasecmp(identifier, "serial") == 0)
+		text = _("Serial service");
+
+	g_object_set(cell, "text", text, NULL);
+
+	g_free(identifier);
+}
+
 GtkWidget *create_service(void)
 {
 	GtkWidget *mainbox;
@@ -212,7 +127,6 @@ GtkWidget *create_service(void)
 	GtkWidget *label;
 	GtkWidget *scrolled;
 	GtkWidget *tree;
-	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *selection;
 
@@ -233,40 +147,18 @@ GtkWidget *create_service(void)
 	gtk_container_add(GTK_CONTAINER(vbox), scrolled);
 
 	tree = gtk_tree_view_new();
-	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree), TRUE);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tree), FALSE);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tree), TRUE);
-	gtk_widget_set_size_request(tree, -1, 160);
+	gtk_widget_set_size_request(tree, -1, 130);
 	gtk_tree_view_set_model(GTK_TREE_VIEW(tree),
 					GTK_TREE_MODEL(service_store));
 
-	gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(tree), 0,
-				_("Name"), gtk_cell_renderer_text_new(),
-						"text", COLUMN_NAME, NULL);
+	gtk_tree_view_insert_column_with_data_func(GTK_TREE_VIEW(tree), 0,
+					"Name", gtk_cell_renderer_text_new(),
+						ident_to_text, NULL, NULL);
 	column = gtk_tree_view_get_column(GTK_TREE_VIEW(tree), 0);
 	gtk_tree_view_column_set_expand(GTK_TREE_VIEW_COLUMN(column), TRUE);
 
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Status"));
-	gtk_tree_view_column_set_spacing(column, 2);
-
-	renderer = gtk_cell_renderer_toggle_new();
-	gtk_tree_view_column_pack_start(column, renderer, FALSE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer,
-						status_to_toggle, NULL, NULL);
-
-	g_signal_connect(G_OBJECT(renderer), "toggled",
-				G_CALLBACK(startstop_callback), NULL);
-
-	renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer,
-						status_to_text, NULL, NULL);
-
-	gtk_tree_view_append_column(GTK_TREE_VIEW(tree), column);
-
-	gtk_tree_view_column_set_min_width(GTK_TREE_VIEW_COLUMN(column), 120);
-	gtk_tree_view_column_set_max_width(GTK_TREE_VIEW_COLUMN(column), 160);
-
 	gtk_container_add(GTK_CONTAINER(scrolled), tree);
 
 	notebook = gtk_notebook_new();
@@ -308,6 +200,7 @@ static void service_free(gpointer data, gpointer user_data)
 
 	service_list = g_list_remove(service_list, service);
 
+	g_free(service->identifier);
 	g_free(service->path);
 	g_free(service);
 }
@@ -337,9 +230,6 @@ static void service_started(DBusGProxy *object, gpointer user_data)
 	struct service_data *service = user_data;
 	const char *busname;
 
-	gtk_list_store_set(service_store, &service->iter,
-					COLUMN_RUNNING, TRUE, -1);
-
 	dbus_g_proxy_call(manager, "ActivateService", NULL,
 			G_TYPE_STRING, service->identifier, G_TYPE_INVALID,
 				G_TYPE_STRING, &busname, G_TYPE_INVALID);
@@ -358,9 +248,6 @@ static void service_stopped(DBusGProxy *object, gpointer user_data)
 {
 	struct service_data *service = user_data;
 
-	gtk_list_store_set(service_store, &service->iter,
-					COLUMN_RUNNING, FALSE, -1);
-
 	if (g_ascii_strcasecmp(service->identifier, "network") == 0)
 		disable_network();
 
@@ -377,8 +264,6 @@ static void add_service(const char *path)
 	GList *list;
 	struct service_data *service;
 	const char *identifier = NULL;
-	const char *name = NULL;
-	const char *description = NULL;
 	gboolean running = FALSE;
 
 	list = g_list_find_custom(service_list, path, service_compare);
@@ -416,24 +301,20 @@ done:
 	dbus_g_proxy_call(object, "GetIdentifier", NULL, G_TYPE_INVALID,
 				G_TYPE_STRING, &identifier, G_TYPE_INVALID);
 
-	dbus_g_proxy_call(object, "GetName", NULL, G_TYPE_INVALID,
-				G_TYPE_STRING, &name, G_TYPE_INVALID);
-
-	dbus_g_proxy_call(object, "GetDescription", NULL, G_TYPE_INVALID,
-				G_TYPE_STRING, &description, G_TYPE_INVALID);
-
-	dbus_g_proxy_call(object, "IsRunning", NULL, G_TYPE_INVALID,
-				G_TYPE_BOOLEAN, &running, G_TYPE_INVALID);
-
-	gtk_list_store_insert_with_values(service_store, &service->iter, -1,
-			COLUMN_PATH, path,
-			COLUMN_IDENT, identifier ? identifier : "",
-			COLUMN_RUNNING, running,
-			COLUMN_NAME, name ? name : path,
-			COLUMN_DESCRIPTION, description ? description : "", -1);
+	if (g_ascii_strcasecmp(identifier, "headset") == 0 ||
+				g_ascii_strcasecmp(identifier, "sink") == 0) {
+		g_object_unref(object);
+		service_free(service, NULL);
+		return;
+	}
 
 	g_free(service->identifier);
 	service->identifier = g_strdup(identifier);
+	if (service->identifier == NULL)
+		service->identifier = g_strdup("");
+
+	gtk_list_store_insert_with_values(service_store, &service->iter, -1,
+			COLUMN_PATH, path, COLUMN_IDENT, identifier, -1);
 
 	if (running == TRUE)
 		service_started(object, service);
@@ -468,9 +349,7 @@ void setup_service(DBusGConnection *conn)
 	GError *error = NULL;
 	const gchar **array = NULL;
 
-	service_store = gtk_list_store_new(6, G_TYPE_STRING, G_TYPE_STRING,
-						G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
-						G_TYPE_STRING, G_TYPE_STRING);
+	service_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 	if (!service_store)
 		return;
 
