@@ -22,4 +22,4 @@
  */
 
 gchar *show_browse_dialog(void);
-GSList *show_select_dialog(void);
+gchar **show_select_dialog(void);
