@@ -71,15 +71,6 @@ static gboolean passkey_agent_request(GObject *agent,
 	return TRUE;
 }
 
-static gboolean passkey_agent_confirm(GObject *agent,
-			const char *path, const char *address,
-			const char *value, DBusGMethodInvocation *context)
-{
-	dbus_g_method_return(context);
-
-	return TRUE;
-}
-
 static gboolean passkey_agent_cancel(GObject *agent,
 			const char *path, const char *address, GError **error)
 {
